==> org-lsst-ccs-subsystem-fcs-buses-5.3.4-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByCarouselClamp.java <==

package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.FilterClampState;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.FilterPresenceStatus;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.LockStatus;

/**
 *
 * A structure for the data published on the status bus by the ClampModule.
 *
 * @author virieux
 *
 */
public class StatusDataPublishedByCarouselClamp implements Serializable {
    private static final long serialVersionUID = 3238914072953604160L;

    private FilterClampState clampState;
    private FilterPresenceStatus filterPresenceStatus;
    private int filterPositionSensorValue;
    private LockStatus lockStatus;
    private int lockSensorValue;
    private double temperature;
    private int filterPresenceOffset1;
    private int filterPresenceOffset2;

    public StatusDataPublishedByCarouselClamp() {
        clampState = FilterClampState.UNDEFINED;
        filterPresenceStatus = FilterPresenceStatus.UNKNOWN;
        filterPositionSensorValue = 0;
        lockStatus = LockStatus.UNKNOWN;
        lockSensorValue = 0;
        temperature = 0;
    }

    public void setFilterPresenceStatus(FilterPresenceStatus filterPositionInClamp) {
        this.filterPresenceStatus = filterPositionInClamp;
    }

    public void setFilterPositionSensorValue(int filterPositionSensorValue) {
        this.filterPositionSensorValue = filterPositionSensorValue;
    }

    public void setLockSensorValue(int lockSensorValue) {
        this.lockSensorValue = lockSensorValue;
    }

    public void setLockStatus(LockStatus lockStatus) {
        this.lockStatus = lockStatus;
    }

    public void setTemperature(double temperature) {
        this.temperature = temperature;
    }

    public double getTemperature() {
        return temperature;
    }

    public FilterPresenceStatus getFilterPresenceStatus() {
        return filterPresenceStatus;
    }

    public int getFilterPositionSensorValue() {
        return filterPositionSensorValue;
    }

    public int getLockSensorValue() {
        return lockSensorValue;
    }

    public LockStatus getLockStatus() {
        return lockStatus;
    }

    public FilterClampState getClampState() {
        return clampState;
    }

    public void setClampState(FilterClampState clampState) {
        this.clampState = clampState;
    }

    public int getFilterPresenceOffset1() {
        return filterPresenceOffset1;
    }

    public void setFilterPresenceOffset1(int lockSensorValueA) {
        this.filterPresenceOffset1 = lockSensorValueA;
    }

    public int getFilterPresenceOffset2() {
        return filterPresenceOffset2;
    }

    public void setFilterPresenceOffset2(int filterPresenceValueA) {
        this.filterPresenceOffset2 = filterPresenceValueA;
    }
    
    


}

==> org-lsst-ccs-subsystem-fcs-buses-5.3.18-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByCarouselClamp.java <==

package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.FilterClampState;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.FilterPresenceStatus;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.LockStatus;

/**
 *
 * A structure for the data published on the status bus by the ClampModule.
 *
 * @author virieux
 *
 */
public class StatusDataPublishedByCarouselClamp implements Serializable {
    private static final long serialVersionUID = 3238914072953604160L;

    private FilterClampState clampState;
    private FilterPresenceStatus filterPresenceStatus;
    private int filterPositionSensorValue;
    private LockStatus lockStatus;
    private int lockSensorValue;
    private double temperature;
    private int filterPresenceOffset1;
    private int filterPresenceOffset2;
    private int actualCurrent;
    private boolean controllerInFault;
    private boolean controllerEnabled;

    public StatusDataPublishedByCarouselClamp() {
        clampState = FilterClampState.UNDEFINED;
        filterPresenceStatus = FilterPresenceStatus.UNKNOWN;
        filterPositionSensorValue = 0;
        lockStatus = LockStatus.UNKNOWN;
        lockSensorValue = 0;
        temperature = 0;
    }

    public void setFilterPresenceStatus(FilterPresenceStatus filterPositionInClamp) {
        this.filterPresenceStatus = filterPositionInClamp;
    }

    public void setFilterPositionSensorValue(int filterPositionSensorValue) {
        this.filterPositionSensorValue = filterPositionSensorValue;
    }

    public void setLockSensorValue(int lockSensorValue) {
        this.lockSensorValue = lockSensorValue;
    }

    public void setLockStatus(LockStatus lockStatus) {
        this.lockStatus = lockStatus;
    }

    public void setTemperature(double temperature) {
        this.temperature = temperature;
    }

    public double getTemperature() {
        return temperature;
    }

    public FilterPresenceStatus getFilterPresenceStatus() {
        return filterPresenceStatus;
    }

    public int getFilterPositionSensorValue() {
        return filterPositionSensorValue;
    }

    public int getLockSensorValue() {
        return lockSensorValue;
    }

    public LockStatus getLockStatus() {
        return lockStatus;
    }

    public FilterClampState getClampState() {
        return clampState;
    }

    public void setClampState(FilterClampState clampState) {
        this.clampState = clampState;
    }

    public int getFilterPresenceOffset1() {
        return filterPresenceOffset1;
    }

    public void setFilterPresenceOffset1(int lockSensorValueA) {
        this.filterPresenceOffset1 = lockSensorValueA;
    }

    public int getFilterPresenceOffset2() {
        return filterPresenceOffset2;
    }

    public void setFilterPresenceOffset2(int filterPresenceValueA) {
        this.filterPresenceOffset2 = filterPresenceValueA;
    }

    public int getActualCurrent() {
        return actualCurrent;
    }

    public boolean isControllerInFault() {
        return controllerInFault;
    }

    public void setControllerInFault(boolean controllerInFault) {
        this.controllerInFault = controllerInFault;
    }

    public boolean isControllerEnabled() {
        return controllerEnabled;
    }

    public void setControllerEnabled(boolean controllerEnabled) {
        this.controllerEnabled = controllerEnabled;
    }

    public void setActualCurrent(int actualCurrent) {
        this.actualCurrent = actualCurrent;
    }

}
